/**
 * @typedef {Object} Options
 * @property {string|string[]} modules List of modules to inline
 * @property {boolean} [ignoreModuleNotFound=false] Ignore the error when modules cannot be found
 *
 * @typedef {import('@babel/core').PluginPass} PluginPass
 * @typedef {import('@babel/core').NodePath} NodePath
 * @typedef {import('@babel/types').StringLiteral} StringLiteral
 * @typedef {import('@babel/types').NumericLiteral} NumericLiteral
 * @typedef {import('@babel/types').BooleanLiteral} BooleanLiteral
 * @typedef {import('@babel/types').NullLiteral} NullLiteral
 * @typedef {import('@babel/types').ImportSpecifier} ImportSpecifier
 * @typedef {import('@babel/types').ImportDefaultSpecifier} ImportDefaultSpecifier
 * @typedef {import('@babel/types').ImportNamespaceSpecifier} ImportNamespaceSpecifier
 */
/**
 * @param {import('@babel/core')} babel
 * @param {Options} options
 * @param {string} cwd
 */
export default function inlineConstants(
  babel: typeof import('@babel/core'),
  options: Options,
  cwd: string
): {
  visitor: {
    ImportDeclaration: (p: NodePath, state: PluginPass) => void
    VariableDeclarator: (p: NodePath, state: PluginPass) => void
    MemberExpression: (p: NodePath, state: PluginPass) => void
    Identifier: (p: NodePath, state: PluginPass) => void
  }
}
export type Options = {
  /**
   * List of modules to inline
   */
  modules: string | string[]
  /**
   * Ignore the error when modules cannot be found
   */
  ignoreModuleNotFound?: boolean
}
export type PluginPass = import('@babel/core').PluginPass
export type NodePath = import('@babel/core').NodePath
export type StringLiteral = import('@babel/types').StringLiteral
export type NumericLiteral = import('@babel/types').NumericLiteral
export type BooleanLiteral = import('@babel/types').BooleanLiteral
export type NullLiteral = import('@babel/types').NullLiteral
export type ImportSpecifier = import('@babel/types').ImportSpecifier
export type ImportDefaultSpecifier = import('@babel/types').ImportDefaultSpecifier
export type ImportNamespaceSpecifier = import('@babel/types').ImportNamespaceSpecifier
